@@ -15,11 +15,12 @@ def response_create_firewall():
                     "source_ips": [
                         "28.239.13.1/32",
                         "28.239.14.0/24",
-                        "ff21:1eac:9a3b:ee58:5ca:990c:8bc9:c03b/128"
+                        "ff21:1eac:9a3b:ee58:5ca:990c:8bc9:c03b/128",
                     ],
                     "destination_ips": [],
                     "protocol": "tcp",
-                    "port": "80"
+                    "port": "80",
+                    "description": None,
                 },
                 {
                     "direction": "out",
@@ -27,69 +28,46 @@ def response_create_firewall():
                     "destination_ips": [
                         "28.239.13.1/32",
                         "28.239.14.0/24",
-                        "ff21:1eac:9a3b:ee58:5ca:990c:8bc9:c03b/128"
+                        "ff21:1eac:9a3b:ee58:5ca:990c:8bc9:c03b/128",
                     ],
                     "protocol": "tcp",
-                    "port": "80"
-                }
+                    "port": "80",
+                    "description": "allow http out",
+                },
             ],
             "applied_to": [
-                {
-                    "server": {
-                        "id": 42
-                    },
-                    "type": "server"
-                },
+                {"server": {"id": 42}, "type": "server"},
                 {
                     "type": "label_selector",
-                    "label_selector": {
-                        "selector": "key==value"
-                    }
-                }
-            ]
+                    "label_selector": {"selector": "key==value"},
+                },
+            ],
         },
         "actions": [
             {
                 "command": "set_firewall_rules",
-                "error": {
-                    "code": "action_failed",
-                    "message": "Action failed"
-                },
+                "error": {"code": "action_failed", "message": "Action failed"},
                 "finished": "2016-01-30T23:56:00+00:00",
                 "id": 13,
                 "progress": 100,
-                "resources": [
-                    {
-                        "id": 38,
-                        "type": "firewall"
-                    }
-                ],
+                "resources": [{"id": 38, "type": "firewall"}],
                 "started": "2016-01-30T23:55:00+00:00",
-                "status": "success"
+                "status": "success",
             },
             {
                 "command": "apply_firewall",
-                "error": {
-                    "code": "action_failed",
-                    "message": "Action failed"
-                },
+                "error": {"code": "action_failed", "message": "Action failed"},
                 "finished": "2016-01-30T23:56:00+00:00",
                 "id": 14,
                 "progress": 100,
                 "resources": [
-                    {
-                        "id": 42,
-                        "type": "server"
-                    },
-                    {
-                        "id": 38,
-                        "type": "firewall"
-                    }
+                    {"id": 42, "type": "server"},
+                    {"id": 38, "type": "firewall"},
                 ],
                 "started": "2016-01-30T23:55:00+00:00",
-                "status": "success"
-            }
-        ]
+                "status": "success",
+            },
+        ],
     }
 
 
@@ -107,11 +85,12 @@ def firewall_response():
                     "source_ips": [
                         "28.239.13.1/32",
                         "28.239.14.0/24",
-                        "ff21:1eac:9a3b:ee58:5ca:990c:8bc9:c03b/128"
+                        "ff21:1eac:9a3b:ee58:5ca:990c:8bc9:c03b/128",
                     ],
                     "destination_ips": [],
                     "protocol": "tcp",
-                    "port": "80"
+                    "port": "80",
+                    "description": "allow http in",
                 },
                 {
                     "direction": "out",
@@ -119,26 +98,20 @@ def firewall_response():
                     "destination_ips": [
                         "28.239.13.1/32",
                         "28.239.14.0/24",
-                        "ff21:1eac:9a3b:ee58:5ca:990c:8bc9:c03b/128"
+                        "ff21:1eac:9a3b:ee58:5ca:990c:8bc9:c03b/128",
                     ],
                     "protocol": "tcp",
-                    "port": "80"
-                }
+                    "port": "80",
+                    "description": "allow http out",
+                },
             ],
             "applied_to": [
-                {
-                    "server": {
-                        "id": 42
-                    },
-                    "type": "server"
-                },
+                {"server": {"id": 42}, "type": "server"},
                 {
                     "type": "label_selector",
-                    "label_selector": {
-                        "selector": "key==value"
-                    }
-                }
-            ]
+                    "label_selector": {"selector": "key==value"},
+                },
+            ],
         }
     }
 
@@ -158,21 +131,15 @@ def two_firewalls_response():
                         "source_ips": [
                             "28.239.13.1/32",
                             "28.239.14.0/24",
-                            "ff21:1eac:9a3b:ee58:5ca:990c:8bc9:c03b/128"
+                            "ff21:1eac:9a3b:ee58:5ca:990c:8bc9:c03b/128",
                         ],
                         "destination_ips": [],
                         "protocol": "tcp",
-                        "port": "80"
+                        "port": "80",
+                        "description": "allow http in",
                     }
                 ],
-                "applied_to": [
-                    {
-                        "server": {
-                            "id": 42
-                        },
-                        "type": "server"
-                    }
-                ]
+                "applied_to": [{"server": {"id": 42}, "type": "server"}],
             },
             {
                 "id": 39,
@@ -186,21 +153,15 @@ def two_firewalls_response():
                         "source_ips": [
                             "28.239.13.1/32",
                             "28.239.14.0/24",
-                            "ff21:1eac:9a3b:ee58:5ca:990c:8bc9:c03b/128"
+                            "ff21:1eac:9a3b:ee58:5ca:990c:8bc9:c03b/128",
                         ],
                         "protocol": "tcp",
-                        "port": "443"
+                        "port": "443",
+                        "description": "allow https in",
                     }
                 ],
-                "applied_to": [
-                    {
-                        "server": {
-                            "id": 42
-                        },
-                        "type": "server"
-                    }
-                ]
-            }
+                "applied_to": [{"server": {"id": 42}, "type": "server"}],
+            },
         ]
     }
 
@@ -221,20 +182,14 @@ def one_firewalls_response():
                         "source_ips": [
                             "28.239.13.1/32",
                             "28.239.14.0/24",
-                            "ff21:1eac:9a3b:ee58:5ca:990c:8bc9:c03b/128"
+                            "ff21:1eac:9a3b:ee58:5ca:990c:8bc9:c03b/128",
                         ],
                         "protocol": "tcp",
-                        "port": "80"
+                        "port": "80",
+                        "description": "allow http in",
                     }
                 ],
-                "applied_to": [
-                    {
-                        "server": {
-                            "id": 42
-                        },
-                        "type": "server"
-                    }
-                ]
+                "applied_to": [{"server": {"id": 42}, "type": "server"}],
             },
         ]
     }
@@ -254,21 +209,15 @@ def response_update_firewall():
                     "source_ips": [
                         "28.239.13.1/32",
                         "28.239.14.0/24",
-                        "ff21:1eac:9a3b:ee58:5ca:990c:8bc9:c03b/128"
+                        "ff21:1eac:9a3b:ee58:5ca:990c:8bc9:c03b/128",
                     ],
                     "destination_ips": [],
                     "protocol": "tcp",
-                    "port": "80"
+                    "port": "80",
+                    "description": "allow http in",
                 }
             ],
-            "applied_to": [
-                {
-                    "server": {
-                        "id": 42
-                    },
-                    "type": "server"
-                }
-            ]
+            "applied_to": [{"server": {"id": 42}, "type": "server"}],
         }
     }
 
@@ -284,16 +233,8 @@ def response_get_actions():
                 "progress": 100,
                 "started": "2016-01-30T23:55:00+00:00",
                 "finished": "2016-01-30T23:56:00+00:00",
-                "resources": [
-                    {
-                        "id": 42,
-                        "type": "firewall"
-                    }
-                ],
-                "error": {
-                    "code": "action_failed",
-                    "message": "Action failed"
-                }
+                "resources": [{"id": 42, "type": "firewall"}],
+                "error": {"code": "action_failed", "message": "Action failed"},
             }
         ]
     }
@@ -310,16 +251,8 @@ def response_set_rules():
                 "progress": 100,
                 "started": "2016-01-30T23:55:00+00:00",
                 "finished": "2016-01-30T23:56:00+00:00",
-                "resources": [
-                    {
-                        "id": 38,
-                        "type": "firewall"
-                    }
-                ],
-                "error": {
-                    "code": "action_failed",
-                    "message": "Action failed"
-                }
+                "resources": [{"id": 38, "type": "firewall"}],
+                "error": {"code": "action_failed", "message": "Action failed"},
             },
             {
                 "id": 14,
@@ -329,19 +262,10 @@ def response_set_rules():
                 "started": "2016-01-30T23:55:00+00:00",
                 "finished": "2016-01-30T23:56:00+00:00",
                 "resources": [
-                    {
-                        "id": 38,
-                        "type": "firewall"
-                    },
-                    {
-                        "id": 42,
-                        "type": "server"
-                    }
+                    {"id": 38, "type": "firewall"},
+                    {"id": 42, "type": "server"},
                 ],
-                "error": {
-                    "code": "action_failed",
-                    "message": "Action failed"
-                }
-            }
+                "error": {"code": "action_failed", "message": "Action failed"},
+            },
         ]
     }
